@@ -70,6 +70,12 @@ impl TokenList {
         Ok(reqwest::get(uri).await?.error_for_status()?.json().await?)
     }
 
+    /// Constructs a [`TokenList`] from the JSON contents of the specified URI.
+    #[cfg(feature = "from-uri-blocking")]
+    pub fn from_uri_blocking<T: reqwest::IntoUrl>(uri: T) -> Result<Self, Error> {
+        Ok(reqwest::blocking::get(uri)?.error_for_status()?.json()?)
+    }
+
     /// Constructs a [`TokenList`] from the JSON contents of the specified URI.
     ///
     /// **Note**: This must be called from a running tokio 0.1.x runtime.
@@ -124,6 +130,16 @@ pub struct Token {
     pub extensions: HashMap<String, Option<ExtensionValue>>,
 }
 
+impl Token {
+    /// Gets the value of `polygonAddress` if present (and a `String`) in the
+    /// `extensions` map.
+    pub fn polygon_address(&self) -> Option<&str> {
+        self.extensions
+            .get("polygonAddress")
+            .and_then(|val| val.as_ref().and_then(|v| v.as_str()))
+    }
+}
+
 /// Definition of a tag that can be associated with a token via its identifier
 #[derive(Serialize, Deserialize, PartialEq, Clone, Debug)]
 #[serde(rename_all = "camelCase")]
@@ -145,6 +161,48 @@ pub enum ExtensionValue {
     Boolean(bool),
 }
 
+impl ExtensionValue {
+    /// If the `ExtensionValue` is a `String`, returns the associated `str`.
+    /// Returns `None` otherwise.
+    pub fn as_str(&self) -> Option<&str> {
+        match self {
+            ExtensionValue::String(val) => Some(val),
+            ExtensionValue::Number(_) => None,
+            ExtensionValue::Boolean(_) => None,
+        }
+    }
+
+    /// If the `ExtensionValue` is a `Boolean`, returns the associated `bool`.
+    /// Returns `None` otherwise.
+    pub fn as_bool(&self) -> Option<bool> {
+        match self {
+            ExtensionValue::String(_) => None,
+            ExtensionValue::Number(_) => None,
+            ExtensionValue::Boolean(val) => Some(*val),
+        }
+    }
+
+    /// If the `ExtensionValue` is a `Number` and an `i64`, returns the
+    /// associated `i64`. Returns `None` otherwise.
+    pub fn as_i64(&self) -> Option<i64> {
+        match self {
+            ExtensionValue::String(_) => None,
+            ExtensionValue::Number(val) => val.as_i64(),
+            ExtensionValue::Boolean(_) => None,
+        }
+    }
+
+    /// If the `ExtensionValue` is a `Number` and an `f64`, returns the
+    /// associated `f64`. Returns `None` otherwise.
+    pub fn as_f64(&self) -> Option<f64> {
+        match self {
+            ExtensionValue::String(_) => None,
+            ExtensionValue::Number(val) => val.as_f64(),
+            ExtensionValue::Boolean(_) => None,
+        }
+    }
+}
+
 /// A number
 #[derive(Serialize, Deserialize, PartialEq, Clone, Copy, Debug)]
 #[serde(untagged)]
@@ -154,8 +212,32 @@ pub enum Number {
     Float(f64),
 }
 
+impl Number {
+    /// If the `Number` is a `i64`, returns the associated `i64`. Returns `None`
+    /// otherwise.
+    pub fn as_i64(&self) -> Option<i64> {
+        match self {
+            Number::Integer(val) => Some(*val),
+            Number::Float(_) => None,
+        }
+    }
+
+    /// If the `Number` is a `f64`, returns the associated `f64`. Returns `None`
+    /// otherwise.
+    pub fn as_f64(&self) -> Option<f64> {
+        match self {
+            Number::Integer(_) => None,
+            Number::Float(val) => Some(*val),
+        }
+    }
+}
+
 /// Represents all errors that can occur when using this library.
-#[cfg(any(feature = "from-uri", feature = "from-uri-compat"))]
+#[cfg(any(
+    feature = "from-uri",
+    feature = "from-uri-blocking",
+    feature = "from-uri-compat"
+))]
 #[derive(thiserror::Error, Debug)]
 pub enum Error {
     /// HTTP/TCP etc. transport level error.
@@ -212,8 +294,13 @@ mod tests {
     #[cfg(feature = "from-uri")]
     #[tokio::test]
     async fn from_uri() {
-        let token_list = TokenList::from_uri(TELCOINS_TOKEN_LIST_URI).await.unwrap();
-        dbg!(&token_list);
+        let _token_list = TokenList::from_uri(TELCOINS_TOKEN_LIST_URI).await.unwrap();
+    }
+
+    #[cfg(feature = "from-uri-blocking")]
+    #[test]
+    fn from_uri_blocking() {
+        let _token_list = TokenList::from_uri_blocking(TELCOINS_TOKEN_LIST_URI).unwrap();
     }
 
     #[cfg(feature = "from-uri-compat")]
@@ -299,9 +386,9 @@ mod tests {
                     "logoURI": "https://raw.githubusercontent.com/telcoin/token-lists/master/assets/logo-telcoin-250x250.png",
                     "tags": ["telcoin"],
                     "extensions": {
-                        "is_mapped_to_matic": true,
-                        "matic_address": "0xdf7837de1f2fa4631d716cf2502f8b230f1dcc32",
-                        "matic_chain_id": 137
+                        "is_mapped_to_polygon": true,
+                        "polygon_address": "0xdf7837de1f2fa4631d716cf2502f8b230f1dcc32",
+                        "polygon_chain_id": 137
                     }
                 }
             ]
@@ -333,17 +420,17 @@ mod tests {
                 tags: vec!["telcoin".to_owned()],
                 extensions: vec![
                     (
-                        "is_mapped_to_matic".to_owned(),
+                        "is_mapped_to_polygon".to_owned(),
                         Some(ExtensionValue::Boolean(true)),
                     ),
                     (
-                        "matic_address".to_owned(),
+                        "polygon_address".to_owned(),
                         Some(ExtensionValue::String(
                             "0xdf7837de1f2fa4631d716cf2502f8b230f1dcc32".to_owned(),
                         )),
                     ),
                     (
-                        "matic_chain_id".to_owned(),
+                        "polygon_chain_id".to_owned(),
                         Some(ExtensionValue::Number(Number::Integer(137))),
                     ),
                 ]
